@@ -572,7 +572,7 @@ class Commands:
 
         return get_reply
 
-    def set_inst(self, type=None, rotxy=None, rotyz=None, rotxz=None) -> [bytes]:
+    def set_inst(self, type=None, rotxy=None, rotyz=None, rotxz=None, led=None) -> [bytes]:
 
         self._reset_buffer()
 
@@ -600,6 +600,12 @@ class Commands:
             else:
                 self.messages.write_warning('Invalid value for ROTXZ in SETINST command')
 
+        if led is not None:
+            if led.upper() in self.ON_OFF:
+                set_inst_command += b',LED="' + led.upper().encode() + b'"'
+            else:
+                self.messages.write_warning('Invalid value for LED in SETINST command')
+
         set_inst_command += b'\r\n'
 
         self.connection.write(set_inst_command)
