@@ -209,10 +209,6 @@ class NucleusDriver:
 
         return self.syslog.set_file_path(path=path)
 
-    def list_syslog(self):
-
-        self.syslog.list_syslog()
-
     def clear_syslog(self) -> [bytes]:
 
         return self.syslog.clear_syslog()
